@@ -1,6 +1,6 @@
 package Build::PPK;
 
-# Copyright (c) 2018, cPanel, L.L.C.
+# Copyright (c) 2012, cPanel, Inc.
 # All rights reserved.
 # http://cpanel.net/
 #
@@ -25,12 +25,12 @@ BEGIN {
     use Exporter ();
     use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
 
-    our $VERSION = '0.07_0001';
-    our @ISA     = qw(Exporter);
+    $VERSION = '0.01';
+    @ISA     = qw(Exporter);
 
-    our @EXPORT      = ();
-    our @EXPORT_OK   = ();
-    our %EXPORT_TAGS = ();
+    @EXPORT      = ();
+    @EXPORT_OK   = ();
+    %EXPORT_TAGS = ();
 }
 
 sub build {
